pub fn create_delayed_stream(
text: impl Into<String>,
delay: Duration,
) -> StreamingResponseExpand description
Create a stream that emits tokens with a delay (for demo purposes)
pub fn create_delayed_stream(
text: impl Into<String>,
delay: Duration,
) -> StreamingResponseCreate a stream that emits tokens with a delay (for demo purposes)